from django.apps import AppConfig


class PrivatesConfig(AppConfig):
    name = "privates"
